use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007000
use Test::Spelling 0.12;
use Pod::Wordlist;

set_spell_cmd('aspell list');
add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
makealongerlink
makeashorterlink
Iain
Truskett
spoon
Chase
Whitener
capoeirab
Dave
Cross
davecross
lib
WWW
Shorten
Shorl
